# Input Widgets

Advanced input widgets: auto-completion, secure password field,
search with history and text editor with tab replacement.

---

## AutoCompleteInput

::: ezqt_widgets.input.auto_complete_input.AutoCompleteInput

---

## PasswordInput

::: ezqt_widgets.input.password_input.PasswordInput

---

## SearchInput

::: ezqt_widgets.input.search_input.SearchInput

---

## TabReplaceTextEdit

::: ezqt_widgets.input.tab_replace_textedit.TabReplaceTextEdit
